#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

import os
import sys
from iobase.xmldata import XmlConfNode
from fal_info import (FAL_SHARES_PATH,
    FAL_SERVICECTRL_PATH, FAL_FTP_PATH, FAL_VALIDATE_PATH)

# debpkg_utils.pyインポート用
sys.path.append(os.path.join(
    os.path.dirname(os.path.abspath(__file__)),
    os.path.pardir))

from debpkg_utils import *

PACKAGE = "ftp"
SERVICE = "proftpd"
USB_CONF_PATH = "/mnt/data/conf/proftpd/usb"
USB_CONF_ANON_PATH = "/mnt/data/conf/proftpd_anon/usb"
REMOVE_LIST = [
    "/mnt/data/etc/proftpd",
    "/mnt/data/etc/proftpd_anon",
    "/mnt/data/conf/proftpd",
    "/mnt/data/conf/proftpd_anon"]

UPDATE_REAL_CONF_CMD_PATH = "/mnt/data/libexec/evh/evh_ftp_mod.py"
TG_LIST_XPATH = "sharelist/share"
PACK_XPATH = "event/eventinfo/shares"
TG_NODE_XPATH = "shareservice/ftp[@enable='true']"

SET_MAN_CMD_PATH = "/mnt/data/libexec/evh/evh_ftp_manual_set.py"

DEFAULT_FAL_CONF_PATH = "/mnt/data/xmlconf/defaults/config-ftp.xml"


class ShareXmlConfModifier(BaseXmlConfModifier):

    FAL = FAL_SHARES_PATH

    class ShareServiceModifyInfo():
        PAR_XPATH = "//shareservice"
        INSTALL_NODE_LIST = [XmlConfNode("<ftp enable='false'/>")]
        REMOVE_XPATH_LIST = ["ftp"]

    MODIFY_INFO_LIST = [ShareServiceModifyInfo]


class ServiceXmlConfModifier(BaseXmlConfModifier):

    FAL = FAL_SERVICECTRL_PATH

    class ShareListModifyInfo():
        PAR_XPATH = "//servicectrl/servicelist"
        INSTALL_NODE_LIST = [
            XmlConfNode("<service enable='true'><name>%s</name></service>" % SERVICE)]
        REMOVE_XPATH_LIST = ["service[name='%s']" % SERVICE]

    class CategoryShareListModifyInfo():
        PAR_XPATH = "//category[name='disk' or name='share' or name='network']/servicelist"
        INSTALL_NODE_LIST = [
            XmlConfNode("<service><name>%s</name></service>" % SERVICE)]
        REMOVE_XPATH_LIST = ["service[name='%s']" % SERVICE]
       
    MODIFY_INFO_LIST = [ShareListModifyInfo, CategoryShareListModifyInfo]


class ValidateXmlConfModifier(BaseXmlConfModifier):

    FAL = FAL_VALIDATE_PATH

    class ForbiddenPortListModifyInfo():
        PAR_XPATH = "nwports/forbidden/portlist"
        INSTALL_NODE_LIST = [
            XmlConfNode("<port service='ftp_data'>20</port>"),
            XmlConfNode("<port service='ftp_control'>21</port>")]
        REMOVE_XPATH_LIST = ["port[@service='ftp_data']", "port[@service='ftp_control']"]

    class UsedPortListModifyInfo():
        PAR_XPATH = "nwports/used/portlist"
        INSTALL_NODE_LIST = [
            XmlConfNode("<port service='ftp_control'>21</port>")]
        REMOVE_XPATH_LIST = ["port[@service='ftp_control']"]
       
    MODIFY_INFO_LIST = [ForbiddenPortListModifyInfo, UsedPortListModifyInfo]


if __name__ == "__main__":
    share_ins = ShareXmlConfModifier()
    service_ins = ServiceXmlConfModifier()
    validate_ins = ValidateXmlConfModifier()
    if sys.argv[1] == "postinst_configure_install":
        share_ins.install()
        service_ins.install()
        validate_ins.install()
        msg_xml_modify_with_file(PACKAGE)
        set_default_conf(FAL_FTP_PATH, DEFAULT_FAL_CONF_PATH)
        update_real_conf(UPDATE_REAL_CONF_CMD_PATH, FAL_SHARES_PATH,
                         TG_LIST_XPATH, PACK_XPATH, TG_NODE_XPATH)
        update_conf(FAL_FTP_PATH)
        ctrl_usb_conf(USB_CONF_PATH)
        ctrl_usb_conf(USB_CONF_ANON_PATH)
        set_package_manual(SET_MAN_CMD_PATH)
        service_start(SERVICE)

    elif sys.argv[1] == "postinst_configure_upgrade":
        # ここで既存の設定に対しての処理をする
        service_start(SERVICE)

    elif sys.argv[1] == "prerm_remove":
        share_ins.remove()
        service_ins.remove()
        validate_ins.remove()
        service_stop(SERVICE)
        remove_files(REMOVE_LIST)

    elif sys.argv[1] == "prerm_upgrade":
        # upgrade時は既存の設定を削除しない
        service_stop(SERVICE)
